@@ -16,8 +16,8 @@ def cdc(rule):
             rx_map(_to_event(rule)),
             rule['publish'](pick(rule,[
                 'logger',
-                'max_batch_size',
-                'bus_name'
+                'bus_name',
+                'source'
             ])),
         )
     return wrapper
